@@ -6,6 +6,7 @@ from __future__ import absolute_import, division, print_function, unicode_litera
 import json
 import os
 import tempfile
+import urllib.parse
 
 from conda._vendor.boltons.setutils import IndexedSet
 from conda.base.constants import ChannelPriority
@@ -53,6 +54,12 @@ def get_index(
     index = []
 
     for url in real_urls:
+        at_count = url.count("@")
+        if at_count > 1:
+            first_at = url.find("@")
+            url = (
+                url[:first_at] + urllib.parse.quote(url[first_at]) + url[first_at + 1 :]
+            )
         channel = Channel(url)
         full_url = CondaHttpAuth.add_binstar_token(
             channel.url(with_credentials=True) + "/" + repodata_fn
@@ -159,7 +166,7 @@ def init_api_context(use_mamba_experimental=False):
 
     if context.ssl_verify is False:
         api_ctx.ssl_verify = "<false>"
-    elif context.ssl_verify is None or context.ssl_verify == "":
+    elif context.ssl_verify is not True:
         api_ctx.ssl_verify = context.ssl_verify
     api_ctx.target_prefix = context.target_prefix
     api_ctx.root_prefix = context.root_prefix
@@ -171,6 +178,7 @@ def init_api_context(use_mamba_experimental=False):
     api_ctx.max_retries = context.remote_max_retries
     api_ctx.retry_backoff = context.remote_backoff_factor
     api_ctx.add_pip_as_python_dependency = context.add_pip_as_python_dependency
+    api_ctx.use_only_tar_bz2 = context.use_only_tar_bz2
 
 
 def to_package_record_from_subjson(channel, pkg, jsn_string):
@@ -203,6 +211,7 @@ def get_installed_packages(prefix, show_channel_urls=None):
     for prec in installed:
         json_rec = prec.dist_fields_dump()
         json_rec["depends"] = prec.depends
+        json_rec["constrains"] = prec.constrains
         json_rec["build"] = prec.build
         result["packages"][prec.fn] = json_rec
 
